﻿using System;
using System.ComponentModel;
using System.Runtime.InteropServices;
using System.Windows;
using System.Windows.Media;

namespace DesktopAlertWithScreenPositionOffset
{
    public class DpiHelper
    {
        private static Matrix transformToDip;

        static DpiHelper()
        {
            IntPtr desktop = GetDC(IntPtr.Zero);
            int pixelsPerInchX = GetDeviceCaps(desktop, DeviceCap.LOGPIXELSX);
            int pixelsPerInchY = GetDeviceCaps(desktop, DeviceCap.LOGPIXELSY);
            transformToDip = Matrix.Identity;
            transformToDip.Scale(96d / (double)pixelsPerInchX, 96d / (double)pixelsPerInchY);
        }

        public static Rect DeviceRectToLogical(Rect deviceRectangle)
        {
            Point topLeft = DevicePixelsToLogical(new Point(deviceRectangle.Left, deviceRectangle.Top));
            Point bottomRight = DevicePixelsToLogical(new Point(deviceRectangle.Right, deviceRectangle.Bottom));
            return new Rect(topLeft, bottomRight);
        }

        public static Point DevicePixelsToLogical(Point devicePoint)
        {
            return transformToDip.Transform(devicePoint);
        }

        [DllImport("user32.dll", EntryPoint = "GetDC", SetLastError = true)]
        private static extern IntPtr _GetDC(IntPtr hwnd);

        [DllImport("gdi32.dll")]
        public static extern int GetDeviceCaps(IntPtr hdc, DeviceCap nIndex);

        public static IntPtr GetDC(IntPtr hwnd)
        {
            IntPtr hdc = _GetDC(hwnd);
            if (IntPtr.Zero == hdc)
            {
                throw new Win32Exception(Marshal.GetLastWin32Error());
            }

            return hdc;
        }

        public enum DeviceCap
        {
            /// <summary>
            /// Logical pixels inch in X.
            /// </summary>
            LOGPIXELSX = 88,

            /// <summary>
            /// Logical pixels inch in Y.
            /// </summary>
            LOGPIXELSY = 90,
        }
    }
}
