﻿using System.Collections.Generic;
using System.Windows;
using System.Windows.Forms;
using System.Windows.Interop;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.InternalWindow.Standard;

namespace DesktopAlertWithScreenPositionOffset
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private Dictionary<Screen, RadDesktopAlertManager> desktopAlertManagersDictionary = new Dictionary<Screen, RadDesktopAlertManager>();

        public MainWindow()
        {
            this.InitializeComponent();
            this.InitializeManagers();
        }

        private void InitializeManagers()
        {
            foreach (var scr in Screen.AllScreens)
            {
                this.desktopAlertManagersDictionary.Add(scr, new RadDesktopAlertManager(AlertScreenPosition.BottomRight, this.CalculateOffset(scr)));
            }
        }

        private Point CalculateOffset(Screen targetScreen)
        {
            var primaryScreen = Screen.PrimaryScreen;
            if (primaryScreen == targetScreen)
            {
                return new Point();
            }

            var primaryScreenRect = DpiHelper.DeviceRectToLogical(new Rect(Screen.PrimaryScreen.WorkingArea.X, Screen.PrimaryScreen.WorkingArea.Y, Screen.PrimaryScreen.WorkingArea.Width, Screen.PrimaryScreen.WorkingArea.Height));
            var targetScreenRect = DpiHelper.DeviceRectToLogical(new Rect(targetScreen.WorkingArea.X, targetScreen.WorkingArea.Y, targetScreen.WorkingArea.Width, targetScreen.WorkingArea.Height));

            var offsetX = targetScreenRect.BottomRight.X - primaryScreenRect.BottomRight.X;
            var offsetY = targetScreenRect.BottomRight.Y - primaryScreenRect.BottomRight.Y;

            return new Point(offsetX, offsetY);
        }


        private void RadButton_Click(object sender, RoutedEventArgs e)
        {
            foreach (var manager in this.desktopAlertManagersDictionary.Values)
            {
                manager.ShowAlert(new RadDesktopAlert { Content = "New Alert", Header = "New Alert" });
            }
        }

        private void RadButton_Click_1(object sender, RoutedEventArgs e)
        {
            var handle = new WindowInteropHelper(this).Handle;
            var currentScreen = Screen.FromHandle(handle);
            this.desktopAlertManagersDictionary[currentScreen].ShowAlert(new RadDesktopAlert { Content = "New Alert", Header = "New Alert" });
        }

        private void Window_LocationChanged(object sender, System.EventArgs e)
        {

        }
    }
}
